summaryrefslogtreecommitdiffstats
path: root/korganizer/kodaymatrix.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:50:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:50:21 -0600
commit3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12 (patch)
tree89de88213bd261e4ccaade899ab2d6ec34b3a5a7 /korganizer/kodaymatrix.cpp
parent1dad5f662a09dfc5cc041caffe0f674044a4dcec (diff)
downloadtdepim-3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.tar.gz
tdepim-3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'korganizer/kodaymatrix.cpp')
-rw-r--r--korganizer/kodaymatrix.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/korganizer/kodaymatrix.cpp b/korganizer/kodaymatrix.cpp
index 0e921e44..1ced5338 100644
--- a/korganizer/kodaymatrix.cpp
+++ b/korganizer/kodaymatrix.cpp
@@ -57,7 +57,7 @@
#undef FocusIn
#undef KeyPress
#undef None
-#undef tqStatus
+#undef Status
#endif
// ============================================================================
@@ -214,9 +214,9 @@ void KODayMatrix::recalculateToday()
mDayLabels[ i ] = TQString::number( KOGlobals::self()->calendarSystem()->day( mDays[i] ));
// if today is in the currently displayed month, hilight today
- if ( mDays[ i ].year() == TQDate::tqcurrentDate().year() &&
- mDays[ i ].month() == TQDate::tqcurrentDate().month() &&
- mDays[ i ].day() == TQDate::tqcurrentDate().day() ) {
+ if ( mDays[ i ].year() == TQDate::currentDate().year() &&
+ mDays[ i ].month() == TQDate::currentDate().month() &&
+ mDays[ i ].day() == TQDate::currentDate().day() ) {
mToday = i;
}
}
@@ -386,15 +386,15 @@ void KODayMatrix::mouseReleaseEvent( TQMouseEvent *e )
mSelEnd = mSelInit;
if (tmp != mSelStart) {
mSelStart = tmp;
- tqrepaint();
+ repaint();
}
} else {
mSelStart = mSelInit;
//tqrepaint only if selection has changed
if (tmp != mSelEnd) {
mSelEnd = tmp;
- tqrepaint();
+ repaint();
}
}
@@ -415,15 +415,15 @@ void KODayMatrix::mouseMoveEvent( TQMouseEvent *e )
mSelEnd = mSelInit;
if ( tmp != mSelStart ) {
mSelStart = tmp;
- tqrepaint();
+ repaint();
}
} else {
mSelStart = mSelInit;
//tqrepaint only if selection has changed
if ( tmp != mSelEnd ) {
mSelEnd = tmp;
- tqrepaint();
+ repaint();
}
}
}
@@ -562,9 +562,9 @@ void KODayMatrix::paintEvent( TQPaintEvent * )
int selw, selh;
bool isRTL = KOGlobals::self()->reverseLayout();
- TQColorGroup cg = tqpalette().active();
+ TQColorGroup cg = palette().active();
- p.tqbegin( &pm, this );
+ p.begin( &pm, this );
pm.fill( cg.base() );
// draw topleft frame
@@ -386,15 +386,15 @@ void KODayMatrix::mouseReleaseEvent( TQMouseEvent *e )
} else {
mSelStart = mSelInit;
- //tqrepaint only if selection has changed
+ //repaint only if selection has changed
if (tmp != mSelEnd) {
mSelEnd = tmp;
@@ -415,15 +415,15 @@ void KODayMatrix::mouseMoveEvent( TQMouseEvent *e )
} else {
mSelStart = mSelInit;
- //tqrepaint only if selection has changed
+ //repaint only if selection has changed
if ( tmp != mSelEnd ) {
mSelEnd = tmp;